package
Version:
v0.0.0-...-40a4eb0
Opens a new window with list of versions in this module.
Published: Sep 7, 2021
License: MIT
Opens a new window with license information.
Imports: 11
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
IDGetName is copied from sis
QQGetName get name using QQ
type AugurData struct {
Places []Place `json:"Places"`
GoodEvents []Event `json:"GoodEvents"`
BadEvents []Event `json:"BadEvents"`
ResetCmds []string `json:"ResetCmds"`
}
type Event struct {
Name string `json:"Name"`
Cmd string `json:"Cmd"`
}
Event includes events and Cmd
type Place struct {
Name string `json:"Name"`
GoodEvents []Event `json:"GoodEvents"`
BadEvents []Event `json:"BadEvents"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.